
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.013.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "PSGI Log handler for Dancer",
  "dist_author" => [
    "Franck Cuny <franck\@lumberjaph.net>"
  ],
  "dist_name" => "Dancer-Logger-PSGI",
  "dist_version" => "v1.0.1",
  "license" => "mit",
  "module_name" => "Dancer::Logger::PSGI",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Dancer" => "1.3059",
    "perl" => "v5.10.0"
  },
  "script_files" => [],
  "test_requires" => {
    "Dancer" => "1.3059",
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Plack::Builder" => 0,
    "Plack::Loader" => 0,
    "Test::More" => 0,
    "Test::TCP" => 0
  }
);


my %fallback_build_requires = (
  "Dancer" => "1.3059",
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.3601",
  "Plack::Builder" => 0,
  "Plack::Loader" => 0,
  "Test::More" => 0,
  "Test::TCP" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
